%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Generate Clusters
% XX November 2006, Release 0.9
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load GoldenQuestion

% Execute this code if you want the Golden Clusters (same seed word)
if GoldenQuestion==1      % flag set in the file Menu.m
    randn('seed',1);    % initialize state of function for repeatability
    rand('seed',1);     % initialize state of function for repeatability
end

% echo some information to the screen
disp('--> Running Generate Clusters')

disp(' '); disp('*** Warning: Be sure to run option 6 first to generate sub-directory structure ***')
disp(' ')

% input the number of realizations to instantiate
if GoldenQuestion~=1
    NumChans = input('Please Input Number of Channels to Generate (e.g. 100) ');
    disp(' ')
else
    NumChans=100; % Golden Cluster Default
end

% define the CM vector to be indexed
CM_vector=[1.1 1.2 1.3 1.4 1.5 2.1 2.2 2.3 2.4 2.5 3.1 3.2 4.1 4.2 4.3 5 6 7 8 9.1 9.2 9.3 10];

% generate the requested realizations for each of the 17 CM models
for CM_vector_index=1:21
    
    ChanNum=CM_vector(CM_vector_index); % fetch CM out of the CM vector
    
    % get channel model params based on this channel model number
    [n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
    LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
    nlos, TSV, SynNLOS] = params( ChanNum );

    % print these parameters out to the screen
    disp(' ')
    disp(strcat('Running Channel Model #',num2str(ChanNum)));
    fprintf(1,['Model Parameters\n' ...
        '  n = %.4f, PLo = %.4f, LowSigma_s = %.4f\n' ...
        '  CapLambda = %.4f, LowLambda = %.4f, CapGamma = %.4f\n' ...
        '  LowGamma = %.4f, LowSigma_c = %.4f, LowSigma_r = %.4f, LowSigma_phi = %.4f\n' ...
        '  L_mean = %.4f, Delta_CapK = %.4f, Delta_LowK = %.4f\n' ...
        '  nlos = %.4f, TSV = %.4f, SynNLOS = %.4f\n'], ...
        n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
        LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
        nlos, TSV, SynNLOS);

    % get a bunch of cluster realizations by calling function "sv"
    sv(n, PLo, LowSigma_s, CapLambda, ... 
    LowLambda, CapGamma, LowGamma, LowSigma_c, LowSigma_r, LowSigma_phi, ... 
    L_mean, Delta_CapK, Delta_LowK, nlos, TSV, SynNLOS, ChanNum, NumChans);  

end